==> apache-skywalking-satellite-0.5.0-src.tgz: apache-skywalking-satellite-0.5.0/plugins/receiver/grpc/nativelog/log_report_service.go <==
// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package nativelog

import (
	"io"
	"time"

	"github.com/apache/skywalking-satellite/plugins/server/grpc"

	common "skywalking.apache.org/repo/goapi/collect/common/v3"
	logging "skywalking.apache.org/repo/goapi/collect/logging/v3"
	v1 "skywalking.apache.org/repo/goapi/satellite/data/v1"
)

const eventName = "grpc-log-event"

type LogReportService struct {
	receiveChannel chan *v1.SniffData
	logging.UnimplementedLogReportServiceServer
}

func (s *LogReportService) Collect(stream logging.LogReportService_CollectServer) error {
	for {
		originalData := grpc.NewOriginalData(nil)
		err := stream.RecvMsg(originalData)
		if err == io.EOF {
			return stream.SendAndClose(&common.Commands{})
		}
		if err != nil {
			return err
		}
		e := &v1.SniffData{
			Name:      eventName,
			Timestamp: time.Now().UnixNano() / 1e6,
			Meta:      nil,
			Type:      v1.SniffType_Logging,
			Remote:    true,
			Data: &v1.SniffData_Log{
				Log: originalData.Content,
			},
		}
		s.receiveChannel <- e
	}
}

==> apache-skywalking-satellite-1.1.0-src.tgz: apache-skywalking-satellite-1.1.0/plugins/receiver/grpc/nativelog/log_report_service.go <==
// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package nativelog

import (
	"io"
	"time"

	"github.com/apache/skywalking-satellite/plugins/server/grpc"

	common "skywalking.apache.org/repo/goapi/collect/common/v3"
	logging "skywalking.apache.org/repo/goapi/collect/logging/v3"
	v1 "skywalking.apache.org/repo/goapi/satellite/data/v1"
)

const eventName = "grpc-log-event"

type LogReportService struct {
	receiveChannel chan *v1.SniffData
	logging.UnimplementedLogReportServiceServer
}

func (s *LogReportService) Collect(stream logging.LogReportService_CollectServer) error {
	dataList := make([][]byte, 0)
	originalData := grpc.NewOriginalData(nil)
	for {
		err := stream.RecvMsg(originalData)
		if err == io.EOF {
			s.flushLogs(dataList)
			return stream.SendAndClose(&common.Commands{})
		}
		if err != nil {
			s.flushLogs(dataList)
			return err
		}
		dataList = append(dataList, originalData.Content)
	}
}

func (s *LogReportService) flushLogs(dataList [][]byte) {
	if len(dataList) == 0 {
		return
	}
	e := &v1.SniffData{
		Name:      eventName,
		Timestamp: time.Now().UnixNano() / 1e6,
		Meta:      nil,
		Type:      v1.SniffType_Logging,
		Remote:    true,
		Data: &v1.SniffData_LogList{
			LogList: &v1.BatchLogList{
				Logs: dataList,
			},
		},
	}
	s.receiveChannel <- e
}
